@@ -1,11 +1,23 @@
 # principal author list is kinda mandated by spec, luckily is rather static
 author 'mst: Matt S Trout <mst@shadowcat.co.uk> (project founder - original idea, architecture and implementation)';
 author 'castaway: Jess Robinson <castaway@desert-island.me.uk> (lions share of the reference documentation and manuals)';
-author 'ribasushi: Peter Rabbitson <ribasushi@cpan.org> (present day maintenance and controlled evolution)';
+author 'ribasushi: Peter Rabbitson <ribasushi@leporine.io> (present day maintenance and controlled evolution)';
 
 # pause sanity
 Meta->{values}{x_authority} = 'cpan:RIBASUSHI';
 
+# !!!experimental!!!
+#
+# <ribasushi> am wondering if an x_parallel_test => 1 and x_parallel_depchain_test => 1 would be of use in meta
+# <ribasushi> to signify "project keeps tabs on itself and depchain to be in good health wrt running tests in parallel"
+# <ribasushi> and having cpan(m) tack a -j6 automatically for that
+# <ribasushi> it basically allows you to first consider any "high level intermediate dist" advertising "all my stuff works" so that larger swaths of CPAN get installed first under parallel
+# <ribasushi> note - this is not "spur of the moment" - I first started testing my depchain in parallel 3 years ago
+# <ribasushi> and have had it stable ( religiously tested on travis on any commit ) for about 2 years now
+#
+Meta->{values}{x_parallel_test_certified} = 1;
+Meta->{values}{x_dependencies_parallel_test_certified} = 1;
+
 # populate x_contributors
 # a direct dump of the sort is ok - xt/authors.t guarantees source sanity
 Meta->{values}{x_contributors} = [ do {
@@ -22,14 +34,13 @@ Meta->{values}{x_contributors} = [ do {
 }];
 
 # legalese
-license 'perl_5';
+license 'perl';
 resources 'license' => 'http://dev.perl.org/licenses/';
 
 # misc resources
 abstract_from 'lib/DBIx/Class.pm';
-resources 'homepage'    => 'http://www.dbix-class.org/';
 resources 'IRC'         => 'irc://irc.perl.org/#dbix-class';
-resources 'repository'  => 'https://github.com/dbsrgits/DBIx-Class';
+resources 'repository'  => 'https://github.com/Perl5/DBIx-Class';
 resources 'MailingList' => 'http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/dbix-class';
 resources 'bugtracker'  => 'http://rt.cpan.org/NoAuth/Bugs.html?Dist=DBIx-Class';
 
@@ -49,7 +60,6 @@ no_index package => $_ for (qw/
   DBIx::Class::Storage::BlockRunner
   DBIx::Class::Carp
   DBIx::Class::_Util
-  DBIx::Class::ResultSet::Pager
 /);
 
 # keep the Makefile.PL eval happy
